@@ -22,12 +22,13 @@ class DocumentModel : public QAbstractListModel
 {
     Q_OBJECT
     Q_PROPERTY(QString name READ name NOTIFY nameChanged)
+    Q_PROPERTY(QString fileName READ fileName NOTIFY nameChanged)
     Q_PROPERTY(bool changed READ changed NOTIFY changedChanged)
     Q_PROPERTY(int activePageIndex READ activePageIndex WRITE setActivePageIndex NOTIFY activePageChanged)
     Q_PROPERTY(QUrl activePageSource READ activePageSource NOTIFY activePageChanged)
     Q_PROPERTY(int activePageRotation READ activePageRotation NOTIFY activePageChanged)
     Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
-
+    
 public:
     enum DocumentModelRoles { ImageUrlRole = Qt::UserRole + 1,
         RotationAngleRole,
@@ -42,10 +43,17 @@ public:
 
     Q_ENUM(RotateOption);
 
+    enum ReorderOption { ReorderDuplex,
+        ReorderDuplexReversed,
+        Reverse};
+
+    Q_ENUM(ReorderOption);
+
     explicit DocumentModel(QObject *parent = nullptr);
     ~DocumentModel();
 
-    const QString name() const;
+    QString name() const;
+    QString fileName() const;
     int activePageIndex() const;
     int activePageRotation() const;
     QUrl activePageSource() const;
@@ -63,11 +71,13 @@ public:
 
     Q_INVOKABLE void rotateImage(int row, RotateOption rotate = RotateOption::Rotate90positive);
 
+    Q_INVOKABLE void reorderPages(ReorderOption reorder);
+
     Q_INVOKABLE void save(const QUrl &fileUrl, QList<int> pageNumbers = {});
 
     Q_INVOKABLE void createSharingFile(const QString &suffix, QList<int> pageNumbers = {});
 
-    Q_INVOKABLE void print();
+    Q_INVOKABLE void exportPDF(const QUrl &fileUrl, const QString &title, const bool useOCR);
 
     QHash<int, QByteArray> roleNames() const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
@@ -79,8 +89,7 @@ Q_SIGNALS:
     void activePageChanged();
     void countChanged();
     void newPageAdded();
-    void saveDocument(const QUrl &fileUrl, const SkanpageUtils::DocumentPages &document, const SkanpageUtils::FileType type = SkanpageUtils::EntireDocument);
-    void printDocument(const SkanpageUtils::DocumentPages &document);
+    void saveDocument(const QUrl &fileUrl, const SkanpageUtils::DocumentPages &document, const SkanpageUtils::FileType type = SkanpageUtils::EntireDocument, const QString &title = QString());
     void saveNewPageTemporary(const int pageID, const QImage &image);
     void sharingDocumentsCreated(const QVariantList &fileUrls);
 
